@@ -81,12 +81,10 @@ class TestAddress(unittest.TestCase):
 
         self.assertEquals(address.street_address, found_address.street_address)
 
+    @raises_with_regexp(NotFoundError,
+        "address for customer 'notreal' with id 'badaddress' not found")
     def test_find_with_invalid_customer_id_and_address_id(self):
-        try:
-            Address.find("notreal", "badaddress")
-            self.assertTrue(False)
-        except NotFoundError as e:
-            self.assertEquals("address for customer 'notreal' with id 'badaddress' not found", str(e))
+        Address.find("notreal", "badaddress")
 
     def test_update_with_valid_values(self):
         customer = Customer.create().customer
