@@ -30,3 +30,17 @@ class TestResourceCollection(unittest.TestCase):
         collection = ResourceCollection("some_query", self.collection_data, TestResourceCollection.TestResource.fetch)
         for test_elem, coll_elem in zip(self.TestResource.items, collection):
             self.assertEqual(test_elem, coll_elem)
+
+    def test_ids_returns_array_of_ids(self):
+        collection = ResourceCollection("some_query", self.collection_data, TestResourceCollection.TestResource.fetch)
+        self.assertEqual(collection.ids, collection_data['search_results']['ids'])
+
+    def test_ids_returns_array_of_ids(self):
+        empty_collection_data = {
+            "search_results": {
+                "page_size": 2,
+                "ids": []
+             }
+         }
+        collection = ResourceCollection("some_query", empty_collection_data, TestResourceCollection.TestResource.fetch)
+        self.assertEqual(collection.ids, [])
